@@ -1,4 +1,4 @@
-# Exports package resources so users can use in their own project.
+# This exports package resources so that anyone can use in their own projects.
 __all__ = [
 	'Scrambler', 'ScramblerGUI',
 	'EncryptionGUI', 'StashGUI',
@@ -8,5 +8,5 @@ __all__ = [
 from .scrambler import *
 from .gui.encryptiongui import *
 from .gui.stashgui import *
-from .utils.instance import *
+from .dircrawler.instance import *
 from .utils.configparser import *
\ No newline at end of file
