@@ -1,23 +1,13 @@
 import os; import random;
 import shlex; import subprocess
 from os.path import isfile, isdir, exists
-from .utils.dircrawler import DirCrawler as dc
-from .utils.encryption import OpenSSLEncyptor as ossl
-from .utils.filemodder import FileModder as fm
+from .dircrawler.crawler import Crawler
+from .dircrawler.filemodder import FileModder
 from .utils.commoncmd import CommonCmd as cmd
+from .utils.encryption import OpenSSLEncyptor as ossl
 
 class Scrambler:
 
-	def formatted_ext(self, raw_extension):
-		if raw_extension == '*':
-			return None
-		if raw_extension == '':
-			return '.txt'
-		if raw_extension[0] != '.':
-			return '.' + raw_extension
-		else:
-			return raw_extension
-
 	def timetravel(self,path,hours_ago=None):
 		if hours_ago == None: hours_ago = random.randrange(1,121000)
 
@@ -35,7 +25,7 @@ class Scrambler:
 			return {'status': 400, 'message': 'Error timetravelling: ' + path}
 
 	def timetravel_files(self, dir, extension=None):
-		files = dc.get_files(dir, extension=extension)
+		files = Crawler.get_files(dir, extension=extension)
 
 		if len(files) <= 0: return {'status': 400, 'message': 'Error timetravelling: no files found.', 'output': []}
 
@@ -43,7 +33,7 @@ class Scrambler:
 		return {'status': 200, 'message': 'Timetravel files complete.', 'output': output}
 
 	def timetravel_folders(self, dir):
-		folders = dc.get_folders(dir)
+		folders = Crawler.get_folders(dir)
 
 		if exists(dir) != True: return {'status': 400, 'message': 'Error timetravelling: no directory found.', 'output': []}
 
@@ -80,7 +70,7 @@ class Scrambler:
 			return errormsg + ' ' + sensitiveinfo
 
 	def stash(self, curr_filename, curr_dir, new_filename, new_dir, overwrite=False, remove=False, censored=True):
-		curr_filepath = dc.joinpath(curr_dir, curr_filename)
+		curr_filepath = Crawler.joinpath(curr_dir, curr_filename)
 		if exists(curr_filepath) != True: return {'status': 400,
 					'message': self._censor_stash_errors(
 						'Error: stash file was not found', curr_filepath, censored)}
@@ -89,7 +79,7 @@ class Scrambler:
 					'message': self._censor_stash_errors(
 						'Error: invalid stash file', curr_filepath, censored)}
 
-		new_filepath = dc.joinpath(new_dir, new_filename)
+		new_filepath = Crawler.joinpath(new_dir, new_filename)
 		if exists(new_filepath) == True and overwrite == False: return {'status': 400,
 					'message': self._censor_stash_errors(
 						'Error: stash file already exists', new_filepath, censored)}
@@ -165,55 +155,55 @@ class Scrambler:
 		result['message'] = '{} completed.'.format(keyword)
 		return result
 
-	def encrypt_msg(self, password, message, decrypt=False):
+	def encrypt_msg(self, password, message, decrypt=False, pbkdf2=True):
 		data = {'medium': 'text', 'input': message, 'outpath': None}
-		result = ossl.encrypt(password, data, decrypt)
-		del password; return result
+		result = ossl.encrypt(password, data, decrypt, pbkdf2)
+		return result
 
 	def encrypt_file(self, password, filepath,
-					decrypt=False, keep_org=False, naked=False):
+					decrypt=False, pbkdf2=True, keep_org=False, naked=False):
 		result = {'status': None, 'message': None}
 		tag_options = {'encrypt' : ['-c'],
 			'decrypt' : ['-d', '-NAKED']}
 
 		if decrypt == True:
 			index = 1 if naked == True else 0
-			outpath = fm.add_tag(filepath,tag_options['decrypt'][index],
+			outpath = FileModder.add_tag(filepath,tag_options['decrypt'][index],
 								tag_options['encrypt'],tag_options['decrypt'])
 		else:
-			outpath = fm.add_tag(filepath,tag_options['encrypt'][0],
+			outpath = FileModder.add_tag(filepath,tag_options['encrypt'][0],
 								tag_options['decrypt'],tag_options['encrypt'])
 
 		if exists(filepath) == False:
 			result['status'] = 400
 			result['message'] = 'Error failed to find file: ' + filepath
-			del password; return result
+			return result
 
 		if exists(outpath) == True:
 			result['status'] = 400
 			result['message'] = 'Error output path already exists: ' + outpath
-			del password; return result
+			return result
 
 		if outpath == filepath:
 			result['status'] = 400
 			result['message'] = 'Action already performed on: ' + filepath
-			del password; return result
+			return result
 
 		data = {'medium': 'file', 'input': filepath, 'outpath': outpath}
-		response = ossl.encrypt(password, data, decrypt)
+		response = ossl.encrypt(password, data, decrypt, pbkdf2)
 		if response['status'] == 400:
 			try:
 				os.remove(outpath)
 			except:
 				pass
-			del password; return response
+			return response
 
 		self.timetravel(outpath)
 
 		if keep_org == True:
 			result['status'] = response['status']
 			result['message'] = response['message'] + ' (original retained).'
-			del password; return result
+			return result
 
 		try:
 			os.remove(filepath)
@@ -223,15 +213,15 @@ class Scrambler:
 			result['status'] = 400
 			result['message'] = response['message'] + ' (Error deleting original).'
 
-		del password; return result
+		return result
 
 	def encrypt_all_files(self, password, wd, extension=None,
-					decrypt=False,keep_org=False,naked=False):
-		filepaths = dc.get_files(wd, extension=extension)
-		if len(filepaths) <= 0: del password; return {'status': 400, 'message': 'Error: No files found.', 'output': []}
+					decrypt=False, pbkdf2=True, keep_org=False, naked=False):
+		filepaths = Crawler.get_files(wd, extension=extension)
+		if len(filepaths) <= 0: return {'status': 400, 'message': 'Error: No files found.', 'output': []}
 
-		output = [self.encrypt_file(password,filepath,
-					decrypt=decrypt,keep_org=keep_org,naked=naked)['message'] for filepath in filepaths]
+		output = [self.encrypt_file(password,filepath,decrypt=decrypt,pbkdf2=pbkdf2,
+					keep_org=keep_org,naked=naked)['message'] for filepath in filepaths]
 
 		timetravel = self.timetravel_folders(wd)
 		if timetravel['status'] != 200 or len(timetravel['output']) == 0:
@@ -239,7 +229,7 @@ class Scrambler:
 		else:
 			for o in timetravel['output']: output.append(o)
 
-		del password; return {'status': 200, 'message': 'Encrypt all files complete.', 'output': output}
+		return {'status': 200, 'message': 'Encrypt all files complete.', 'output': output}
 
 class ScramblerGUI:
 
@@ -254,6 +244,7 @@ class ScramblerGUI:
 		print('Welcome to the Scrambler!')
 
 	def optionscreen(self):
+		print('version: ' + self.instance.version_text)
 		print(' ')
 		print('What would you like to do?')
 		print('(s) Set Dir, (e) Encrypt, (d) Decrypt, (st) Stash, (t) Timetravel, (q) Quit')
@@ -262,6 +253,25 @@ class ScramblerGUI:
 		cmd.clear()
 		print('Feature not yet available, no action taken.')
 
+	def option_pwd(self):
+		cmd.clear()
+		if self.instance.wd == None:
+			print('Error: No working directory set. Please set working directory first.'); return
+		else:
+			print('Working directory: {}'.format(cmd.pwd())); return
+
+	def option_ls(self):
+		cmd.clear()
+		if self.instance.wd == None:
+			print('Error: No working directory set. Please set working directory first.'); return
+
+		ls = cmd.ls()
+
+		if len(ls) == 0:
+			print('Working directory is empty.'); return
+		else:
+			print(' '.join(ls)); return
+
 	def option_s(self):
 		print(' ')
 		print('What directory do you want to set as your working directory?')
@@ -284,7 +294,7 @@ class ScramblerGUI:
 		print('Use * to timetravel all files regardless of type (this can be dangerous).')
 		print(' ')
 		raw_extension = input('Specify a file type [Optional]: ')
-		extension = self.scrambler.formatted_ext(raw_extension)
+		extension = FileModder.format_ext(raw_extension, ifblank='.txt')
 		print(' ')
 		if extension == None:
 			confirm = input('Are you sure you want to timetravel all folders and files of all types [y/n]: ')
@@ -311,25 +321,6 @@ class ScramblerGUI:
 		print('Timetravel complete.')
 		input(); cmd.clear(); return
 
-	def option_pwd(self):
-		cmd.clear()
-		if self.instance.wd == None:
-			print('Error: No working directory set. Please set working directory first.'); return
-		else:
-			print('Working directory: {}'.format(cmd.pwd())); return
-
-	def option_ls(self):
-		cmd.clear()
-		if self.instance.wd == None:
-			print('Error: No working directory set. Please set working directory first.'); return
-
-		ls = cmd.ls()
-
-		if len(ls) == 0:
-			print('Working directory is empty.'); return
-		else:
-			print(' '.join(ls)); return
-
 	def run(self):
 		cmd.clear()
 		self.splashscreen()
@@ -338,7 +329,7 @@ class ScramblerGUI:
 			self.optionscreen()
 			select = input()
 
-			if select not in ('s','e','d','st','t','q','pwd','ls'):
+			if select not in ('pwd','ls','s','e','d','st','t','q'):
 				#'(s) Set Dir, (e) Encrypt, (d) Decrypt, (st) Stash, (t) Timetravel, (q) Quit'
 				cmd.clear(); print('Invalid selection. Try again.')
 
